---
title: Nuxt
icon: i-logos-nuxt-icon
description: Using the Unlighthouse Nuxt module allows you to close the feedback loop in fixing your Google Lighthouse issues in your development site.
---

::u-alert{type="warning"}
This integration is now deprecated and will be removed in the v1 major release.
Read more about [integration deprecations](/integration-deprecations).
::

Using the Unlighthouse Nuxt module allows you to close the feedback loop in fixing your Google Lighthouse issues in your
development site.

## Install

::code-group

```bash [yarn]
yarn add -D @unlighthouse/nuxt
```

```bash [npm]
npm install -D @unlighthouse/nuxt
```

```bash [pnpm]
pnpm add -D @unlighthouse/nuxt
```

::

### Git ignore reports

Unlighthouse will save your reports in `outputDir` (`.unlighthouse` by default),
it's recommended you .gitignore these files.

```
.unlighthouse
```

## Usage

To begin using Unlighthouse, you'll need to add the module to `buildModules`.

When you run your Nuxt app, it will give you the URL of client, only once you visit the client will Unlighthouse start.

### Nuxt 3

```js nuxt.config.ts
import { defineNuxtConfig } from 'nuxt3'

export default defineNuxtConfig({
  modules: [
    '@unlighthouse/nuxt',
  ],
})
```

### Nuxt 2

```js nuxt.config.js
export default {
  buildModules: [
    '@unlighthouse/nuxt',
  ],
}
```

Type support can be added by adding the `@unlighthouse/nuxt` module to your `plugins`. Nuxt v3 will automatically add type support.

```json tsconfig.json
{
  "compilerOptions": {
    "types": [
      "@unlighthouse/nuxt"
    ]
  }
}
```

## Configuration

You can either configure Unlighthouse via the `unlighthouse` key in your Nuxt config, or you can provide a `unlighthouse.config.ts` file
in the root directory.

### Example

```js nuxt.config.js
export default {
  unlighthouse: {
    scanner: {
      // simulate a desktop device
      device: 'desktop',
    }
  }
}
```
